@@ -14,7 +14,6 @@
 #include <QString>
 #include <QUrl>
 
-class FlatpakReferencesModel;
 class FlatpakPermissionModel;
 
 // Slightly similar to FlatpakResource from libdiscover
@@ -23,26 +22,21 @@ class FlatpakReference : public QObject
     Q_OBJECT
     Q_PROPERTY(QString version READ version CONSTANT FINAL)
     Q_PROPERTY(QString displayName READ displayName CONSTANT FINAL)
-    Q_PROPERTY(QUrl iconSource READ iconSource CONSTANT FINAL)
 
 public:
-    explicit FlatpakReference(FlatpakReferencesModel *parent,
-                              const QString &flatpakName,
+    explicit FlatpakReference(const QString &flatpakName,
                               const QString &arch,
                               const QString &branch,
                               const QString &version,
                               const QString &displayName,
-                              const QUrl &iconSource,
                               const QStringList &metadataAndOverridesFiles);
 
-    FlatpakReferencesModel *parent() const;
+    static std::vector<std::unique_ptr<FlatpakReference>> allFlatpakReferences();
 
     QString arch() const;
     QString branch() const;
     QString version() const;
 
-    QUrl iconSource() const;
-
     const QStringList &metadataAndOverridesFiles() const;
     QStringList defaultsFiles() const;
     const QString &userLevelPerAppOverrideFile() const;
@@ -60,10 +54,6 @@ public:
     bool isSaveNeeded() const;
     bool isDefaults() const;
 
-Q_SIGNALS:
-    void needsLoad();
-    void settingsChanged();
-
 private:
     // ID of a ref constitutes of these three members:
     QString m_flatpakName;
@@ -75,7 +65,6 @@ private:
     // Might be empty, in which case code should fallback to flatpakName.
     QString m_displayName;
 
-    QUrl m_iconSource;
     // List of metadata and overrides files, in the order they should be
     // loaded and merged, starting from base app metadata and ending with
     // per-app user-level override.
@@ -83,37 +72,3 @@ private:
 
     QPointer<FlatpakPermissionModel> m_permissionsModel;
 };
-
-class FlatpakReferencesModel : public QAbstractListModel
-{
-    Q_OBJECT
-public:
-    explicit FlatpakReferencesModel(QObject *parent = nullptr);
-
-    enum Roles {
-        Name = Qt::DisplayRole,
-        Icon = Qt::DecorationRole,
-        Version = Qt::UserRole + 1,
-        Ref,
-    };
-    Q_ENUM(Roles)
-
-    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
-    QHash<int, QByteArray> roleNames() const override;
-
-    void load(int index);
-    void save(int index);
-    void defaults(int index);
-    bool isSaveNeeded(int index) const;
-    bool isDefaults(int index) const;
-
-    const QList<FlatpakReference *> &references() const;
-
-Q_SIGNALS:
-    void needsLoad();
-    void settingsChanged();
-
-private:
-    QList<FlatpakReference *> m_references;
-};
